@@ -3,9 +3,8 @@
 # INPUT normalized_calib.tsv: normalized_calib.tsv TYPE GENE_EXPRS 
 # OUTPUT smoothed.tsv: smoothed.tsv 
 
-# smooth-acgh.R
 # Ilari Scheinin <firstname.lastname@gmail.com>
-# 2011-12-09
+# 2013-02-13
 
 source(file.path(chipster.common.path, 'CGHcallPlus.R'))
 library(NoWaves)
@@ -13,7 +12,8 @@ library(NoWaves)
 pos <- c('chromosome','start','end')
 
 # load tumor data and preprocess to deal with missing values
-dat <- read.table('normalized_tumor.tsv', header=TRUE, sep='\t', as.is=TRUE, row.names=1)
+file1 <- 'normalized_tumor.tsv'
+dat <- read.table(file1, header=TRUE, sep='\t', quote='', row.names=1, as.is=TRUE, check.names=FALSE)
 if (length(setdiff(pos, colnames(dat)))!=0)
   stop('CHIPSTER-NOTE: Your cancer data set needs to have the following columns: chromosome, start, end.')
 dat <- data.frame(probe=rownames(dat), dat, stringsAsFactors=FALSE)
@@ -21,12 +21,15 @@ dat$chromosome[dat$chromosome=='X'] <- 23
 dat$chromosome[dat$chromosome=='Y'] <- 24
 dat$chromosome[dat$chromosome=='MT'] <- 25
 dat$chromosome <- as.integer(dat$chromosome)
+dat.anno <- dat[,setdiff(colnames(dat), c('probe', 'chromosome', 'start', 'end', grep('chip\\.', colnames(dat), value=TRUE)))]
+dat <- dat[,c('probe', 'chromosome', 'start', 'end', grep('chip\\.', colnames(dat), value=TRUE))]
 cgh <- make_cghRaw(dat)
 cgh <- preprocess(cgh, nchrom=23)
-cgh <- data.frame(Probe=rownames(cgh@featureData@data), cgh@featureData@data, assayDataElement(cgh, 'copynumber'))
+cgh <- data.frame(Probe=rownames(fData(cgh)), fData(cgh), copynumber(cgh), stringsAsFactors=FALSE)
 
 # load calibration data and preprocess to deal with missing values
-dat2 <- read.table('normalized_calib.tsv', header=TRUE, sep='\t', as.is=TRUE, row.names=1)
+file2 <- 'normalized_calib.tsv'
+dat2 <- read.table(file2, header=TRUE, sep='\t', quote='', row.names=1, as.is=TRUE, check.names=FALSE)
 if (length(setdiff(pos, colnames(dat2)))!=0)
   stop('CHIPSTER-NOTE: Your calibration data set needs to have the following columns: chromosome, start, end.')
 dat2 <- data.frame(probe=rownames(dat2), dat2, stringsAsFactors=FALSE)
@@ -34,9 +37,10 @@ dat2$chromosome[dat2$chromosome=='X'] <- 23
 dat2$chromosome[dat2$chromosome=='Y'] <- 24
 dat2$chromosome[dat2$chromosome=='MT'] <- 25
 dat2$chromosome <- as.integer(dat2$chromosome)
+dat2 <- dat2[,c('probe', 'chromosome', 'start', 'end', grep('chip\\.', colnames(dat2), value=TRUE))]
 calib <- make_cghRaw(dat2)
 calib <- preprocess(calib, nchrom=23)
-calib <- data.frame(Probe=rownames(calib@featureData@data), calib@featureData@data, assayDataElement(calib, 'copynumber'))
+calib <- data.frame(Probe=rownames(fData(calib)), fData(calib), copynumber(calib), stringsAsFactors=FALSE)
 
 # dewave tumor data
 calib <- SmoothNormals(calib)
@@ -50,9 +54,11 @@ dewaved$chromosome <- as.character(dewaved$chromosome)
 dewaved$chromosome[dewaved$chromosome=='23'] <- 'X'
 dewaved$chromosome[dewaved$chromosome=='24'] <- 'Y'
 dewaved$chromosome[dewaved$chromosome=='25'] <- 'MT'
-dewaved[,-(1:4)] <- round(dewaved[,-(1:4)], digits=2)
+dewaved[,-(1:3)] <- round(dewaved[,-(1:3)], digits=2)
+dewaved <- cbind(dewaved[,1:3], dat.anno[rownames(dewaved),], dewaved[,-(1:3)])
 
 # write results
-write.table(dewaved, file='smoothed.tsv', quote=FALSE, sep='\t', col.names=TRUE, row.names=TRUE)
+options(scipen=10)
+write.table(dewaved, file='smoothed.tsv', quote=FALSE, sep='\t', na='')
 
 # EOF
