@@ -5,7 +5,7 @@
 # PARAMETER coloring.scheme: coloring.scheme TYPE [Green-Red: Green-Red, Blue-Yellow: Blue-Yellow, Black-White: Black-White] DEFAULT Blue-Yellow (Coloring scheme for the SOM map)
 # PARAMETER cluster.samples.only: cluster.samples.only TYPE [yes: yes, no: no] DEFAULT no (Disables clustering on the genes. This option is convenient if you want to retain a predefined gene order or make a sample clustering heatmap with more than 10000 genes)
 # PARAMETER hm.scale: hm.scale TYPE [default: default, none: none, row: row, column: column] DEFAULT default (Indicating if the values should be centered and scaled in either the row direction or the column direction, or none.)
-# PARAMETER distance: distance TYPE [euclidean: euclidean, maximum: maximum, manhattan: manhattan, canberra: canberra, binary: binary, minkowski: minkowski, pearson: pearson, spearman: spearman, kendall: kendall, cosine: cosine, mcd: mcd, ogk: ogk] DEFAULT pearson (The correlation distance measure to be used for clustering.)
+# PARAMETER distance: distance TYPE [euclidean: euclidean, maximum: maximum, manhattan: manhattan, canberra: canberra, binary: binary, pearson: pearson, spearman: spearman, kendall: kendall] DEFAULT pearson (The correlation distance measure to be used for clustering.)
 # PARAMETER image.width: image.width TYPE INTEGER FROM 200 TO 3200 DEFAULT 600 (Width of the plotted network image)
 # PARAMETER image.height: image.height TYPE INTEGER FROM 200 TO 3200 DEFAULT 600 (Height of the plotted network image)
 
@@ -25,6 +25,11 @@
 # added parameter hm.scale, see parameter scale of heatmap function, R: help(heatmap)
 # added parameter distance, see parameter distfun of heatmap function, to allow for different distance measurements
 #
+# OH 11.06.2013
+# switching back from function hclust (used by function heatmap) to pre-calc dendrogram with function hcluster:
+#   visualization "plot-dendrogram.R" produced a different dendrogram than plot-heatmap.R with same parameters
+#   because of usage of different functions hcluster and hclust.
+#
 
 
 # Parameter settings (default) for testing purposes
@@ -40,17 +45,13 @@ h<-image.height
 
 s<-hm.scale
 d<-distance
-library("MKmisc")
-#myCorDist=function(x){dist(x)}
-if( d=="euclidean" || d=="maximum" || d=="manhattan" || d=="canberra" || d=="binary" || d=="minkowski" ) {
-	myCorDist=function(x){dist(x,method=d)}
-}
-if( d=="pearson" || d=="spearman" || d=="kendall" || d=="cosine" || d=="mcd" || d=="ogk" ) {
-	myCorDist=function(x){corDist(x,method=d)}
+
+if(d=="pearson") {
+   d<-"correlation"
 }
 
 # Loading the libraries
-#library(amap)
+library(amap)
 
 # Loads the normalized data
 file<-c("normalized.tsv")
@@ -72,12 +73,6 @@ if (ncol(dat2) > 20000) {
 phenodata<-read.table("phenodata.tsv", header=T, sep="\t")
 colnames(dat2)<-gsub(" ", "", phenodata$description)
 
-# Does the clustering
-#if (cluster.samples.only=="no") {
-#	clustg<-as.dendrogram(hcluster(x=dat2, method="pearson", link="average"))
-#}
-#clustc<-as.dendrogram(hcluster(x=t(dat2), method="pearson", link="average"))
-
 # Generating the colors
 if(colpar=="Green-Red") {
 	heatcol<-colorRampPalette(c("Green", "Red"))(32)
@@ -101,24 +96,43 @@ if(colpar=="Black-White") {
 	if (nrow(dat2)<=50) {
 		column_margin <- 15
 	}
-	
+
+# Does the clustering
+#if (cluster.samples.only=="no") {
+#	clustg<-as.dendrogram(hcluster(x=dat2, method="pearson", link="average"))
+#}
+#clustc<-as.dendrogram(hcluster(x=t(dat2), method="pearson", link="average"))
+
+#library("MKmisc")
+#if( d=="euclidean" || d=="maximum" || d=="manhattan" || d=="canberra" || d=="binary" || d=="minkowski" ) {
+#	myCorDist=function(x){dist(x,method=d)}
+#}
+#if( d=="pearson" || d=="spearman" || d=="kendall" || d=="cosine" || d=="mcd" || d=="ogk" ) {
+#	myCorDist=function(x){corDist(x,method=d)}
+#}
+
+if (cluster.samples.only=="no") {
+	clustg<-as.dendrogram(hcluster(x=dat2, method=d, link="average"))
+}
+clustc<-as.dendrogram(hcluster(x=t(dat2), method=d, link="average"))
+
 pdf(file="heatmap.pdf", width=w/72, height=h/72)
 if (cluster.samples.only=="no") {
 	if( hm.scale=="default" ) {
-		#heatmap(x=as.matrix(dat2), Rowv=clustg, Colv=clustc, distfun=myCorDist, col=heatcol, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
-		heatmap(x=as.matrix(dat2), distfun=myCorDist, col=heatcol, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
+		heatmap(x=as.matrix(dat2), Rowv=clustg, Colv=clustc, col=heatcol, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
+		#heatmap(x=as.matrix(dat2), distfun=myCorDist, hclustfun=hclust, col=heatcol, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
 	} else {
-		#heatmap(x=as.matrix(dat2), Rowv=clustg, Colv=clustc, distfun=myCorDist, col=heatcol, scale=s, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
-		heatmap(x=as.matrix(dat2), distfun=myCorDist, col=heatcol, scale=s, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
+		heatmap(x=as.matrix(dat2), Rowv=clustg, Colv=clustc, col=heatcol, scale=s, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
+		#heatmap(x=as.matrix(dat2), distfun=myCorDist, hclustfun=hclust, col=heatcol, scale=s, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
 	}
 }
 if (cluster.samples.only=="yes") {
 	if( hm.scale=="default" ) {
-		#heatmap(x=as.matrix(dat2), Rowv=NA, Colv=clustc, distfun=myCorDist, col=heatcol, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
-		heatmap(x=as.matrix(dat2), Rowv=NA, distfun=myCorDist, col=heatcol, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
+		heatmap(x=as.matrix(dat2), Rowv=NA, Colv=clustc, col=heatcol, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
+		#heatmap(x=as.matrix(dat2), Rowv=NA, distfun=myCorDist, hclustfun=hclust, col=heatcol, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
 	} else {
-		#heatmap(x=as.matrix(dat2), Rowv=NA, Colv=clustc, distfun=myCorDist, col=heatcol, scale=s, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
-		heatmap(x=as.matrix(dat2), Rowv=NA, distfun=myCorDist, col=heatcol, scale=s, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
+		heatmap(x=as.matrix(dat2), Rowv=NA, Colv=clustc, col=heatcol, scale=s, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
+		#heatmap(x=as.matrix(dat2), Rowv=NA, distfun=myCorDist, hclustfun=hclust, col=heatcol, scale=s, margins=c(15, column_margin), labCol=gsub(" ", "", phenodata$description))
 	}
 }
 dev.off()
