@@ -41,7 +41,13 @@ if (species == "Rat") {
 
 # Read in data and extract the identifiers
 ensembl_list <- read.table (file="ensembl-list.tsv", sep="\t", header=T)
-ensembl_id_list <- as.character(unique(ensembl_list$ensembl_id))
+if("ensembl_id" %in% colnames(ensembl_list)) {
+	ensembl_id_list <- as.character(unique(ensembl_list$ensembl_id))
+} else {
+	ensembl_id_list <- rownames(ensembl_list)
+}
+
+print(ensembl_id_list[1:10])
 
 # Fetch additional gene info from BioMart database
 ensembl_annotations <- useMart("ensembl", dataset=as.character(ensembl_dataset))
