@@ -7,7 +7,7 @@
  * Project Info:  http://www.jfree.org/jfreechart/index.html
  *
  * This library is free software; you can redistribute it and/or modify it 
- * under the terms of the GNU Lesser General Public License as publihed by 
+ * under the terms of the GNU Lesser General Public License as published by 
  * the Free Software Foundation; either version 2.1 of the License, or 
  * (at your option) any later version.
  *
@@ -34,8 +34,10 @@
  *                   Nicolas Brodu (for Astrium and EADS Corporate Research 
  *                   Center);
  *
- * Changes
- * -------
+ * $Id: ValueAxis.java,v 1.10.2.5 2007/03/22 12:13:27 mungady Exp $
+ *
+ * Changes (from 18-Sep-2001)
+ * --------------------------
  * 18-Sep-2001 : Added standard header and fixed DOS encoding problem (DG);
  * 23-Nov-2001 : Overhauled standard tick unit code (DG);
  * 04-Dec-2001 : Changed constructors to protected, and tidied up default 
@@ -95,7 +97,6 @@
  * ------------- JFREECHART 1.0.x ---------------------------------------------
  * 10-Oct-2006 : Source reformatting (DG);
  * 22-Mar-2007 : Added new defaultAutoRange attribute (DG);
- * 02-Aug-2007 : Check for major tick when drawing label (DG);
  *
  */
 
@@ -696,8 +697,7 @@ public abstract class ValueAxis extends Axis
                         tick.getAngle(), tick.getRotationAnchor());
             }
 
-            if (isTickMarksVisible() && tick.getTickType().equals(
-                    TickType.MAJOR)) {
+            if (isTickMarksVisible()) {
                 float xx = (float) valueToJava2D(tick.getValue(), dataArea, 
                         edge);
                 Line2D mark = null;
@@ -1034,7 +1034,6 @@ public abstract class ValueAxis extends Axis
      * @return The default auto range (never <code>null</code>).
      * 
      * @see #setDefaultAutoRange(Range)
-     *
      * @since 1.0.5
      */
     public Range getDefaultAutoRange() {
@@ -1485,8 +1484,6 @@ public abstract class ValueAxis extends Axis
      * To halve the length of the axis range, use 50% (0.5).
      *
      * @param percent  the resize factor.
-     * 
-     * @see #resizeRange(double, double)
      */
     public void resizeRange(double percent) {
         resizeRange(percent, this.range.getCentralValue());
@@ -1502,8 +1499,6 @@ public abstract class ValueAxis extends Axis
      *
      * @param percent  the resize factor.
      * @param anchorValue  the new central value after the resize.
-     * 
-     * @see #resizeRange(double)
      */
     public void resizeRange(double percent, double anchorValue) {
         if (percent > 0.0) {
